@@ -33,6 +33,8 @@ class SimpletransformersBertModel(BaseEstimator, ClassifierMixin):
             save_steps=-1,
             save_eval_checkpoints=False,
             save_model_every_epoch=False,
+            no_cache=False,
+            no_save=False,
             eval_all_checkpoints=True,
             use_tensorboard=False,
             overwrite_output_dir=False,
@@ -75,8 +77,25 @@ class SimpletransformersBertModel(BaseEstimator, ClassifierMixin):
         self.sliding_window = sliding_window
         self.save_eval_checkpoints = save_eval_checkpoints
         self.save_model_every_epoch = save_model_every_epoch
+        self.no_cache = no_cache
+        self.no_save = no_save
 
-        self.model_args = {
+    def fit(self, x, y, *args, **kwargs):
+        """Fit the model."""
+        self.label_encoder = LabelEncoder()
+        y = self.label_encoder.fit_transform(y)
+        targets = set(y)
+        n_classes = len(targets)
+
+        for target in targets:
+            if target >= n_classes:
+                raise Exception(
+                    f'target {target} is larger than n_classes ({n_classes}). '
+                    'this is not supported by pytorch and will cause a very '
+                    'hard to debug error.'
+                )
+
+        model_args = {
             'model_type': self.model_type,
             'pretrained_model': self.pretrained_model,
             'output_dir': self.output_dir,
@@ -107,28 +126,15 @@ class SimpletransformersBertModel(BaseEstimator, ClassifierMixin):
             'sliding_window': self.sliding_window,
             'save_eval_checkpoints': self.save_eval_checkpoints,
             'save_model_every_epoch': self.save_model_every_epoch,
+            'no_save': self.no_save,
+            'no_cache': self.no_cache,
         }
 
-    def fit(self, x, y, *args, **kwargs):
-        """Fit the model."""
-        self.label_encoder = LabelEncoder()
-        y = self.label_encoder.fit_transform(y)
-        targets = set(y)
-        n_classes = len(targets)
-
-        for target in targets:
-            if target >= n_classes:
-                raise Exception(
-                    f'target {target} is larger than n_classes ({n_classes}). '
-                    'this is not supported by pytorch and will cause a very '
-                    'hard to debug error.'
-                )
-
         self.model = ClassificationModel(
             self.model_type,
             self.pretrained_model,
             num_labels=n_classes,
-            args=self.model_args,
+            args=model_args,
             use_cuda=self.use_cuda,
         )
         df = pd.DataFrame(dict(text=x, labels=y))
